/*
 * Copyright (C) 2010-2021 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1.  Redistributions of source code must retain the above copyright
 *     notice, this list of conditions and the following disclaimer.
 * 2.  Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. AND ITS CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR ITS CONTRIBUTORS BE LIABLE FOR
 * ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#include "config.h"
#if USE(LIBWEBRTC)
#include "NetworkRTCProvider.h"

#include "ArgumentCoders.h"
#include "DataReference.h"
#include "Decoder.h"
#include "HandleMessage.h"
#include "LibWebRTCResolverIdentifier.h"
#include "NetworkRTCProviderMessages.h"
#include "RTCNetwork.h"
#include "RTCPacketOptions.h"
#include "WebCoreArgumentCoders.h"
#include <WebCore/LibWebRTCSocketIdentifier.h>
#include <wtf/text/WTFString.h>

namespace WebKit {

void NetworkRTCProvider::didReceiveMessage(IPC::Connection& connection, IPC::Decoder& decoder)
{
    auto protectedThis = makeRef(*this);
    if (decoder.messageName() == Messages::NetworkRTCProvider::CreateUDPSocket::name()) {
        IPC::handleMessage<Messages::NetworkRTCProvider::CreateUDPSocket>(decoder, this, &NetworkRTCProvider::createUDPSocket);
        return;
    }
    if (decoder.messageName() == Messages::NetworkRTCProvider::CreateServerTCPSocket::name()) {
        IPC::handleMessage<Messages::NetworkRTCProvider::CreateServerTCPSocket>(decoder, this, &NetworkRTCProvider::createServerTCPSocket);
        return;
    }
    if (decoder.messageName() == Messages::NetworkRTCProvider::CreateClientTCPSocket::name()) {
        IPC::handleMessage<Messages::NetworkRTCProvider::CreateClientTCPSocket>(decoder, this, &NetworkRTCProvider::createClientTCPSocket);
        return;
    }
    if (decoder.messageName() == Messages::NetworkRTCProvider::WrapNewTCPConnection::name()) {
        IPC::handleMessage<Messages::NetworkRTCProvider::WrapNewTCPConnection>(decoder, this, &NetworkRTCProvider::wrapNewTCPConnection);
        return;
    }
    if (decoder.messageName() == Messages::NetworkRTCProvider::SetPlatformSocketsEnabled::name()) {
        IPC::handleMessage<Messages::NetworkRTCProvider::SetPlatformSocketsEnabled>(decoder, this, &NetworkRTCProvider::setPlatformSocketsEnabled);
        return;
    }
    if (decoder.messageName() == Messages::NetworkRTCProvider::CreateResolver::name()) {
        IPC::handleMessage<Messages::NetworkRTCProvider::CreateResolver>(decoder, this, &NetworkRTCProvider::createResolver);
        return;
    }
    if (decoder.messageName() == Messages::NetworkRTCProvider::StopResolver::name()) {
        IPC::handleMessage<Messages::NetworkRTCProvider::StopResolver>(decoder, this, &NetworkRTCProvider::stopResolver);
        return;
    }
    if (decoder.messageName() == Messages::NetworkRTCProvider::SendToSocket::name()) {
        IPC::handleMessage<Messages::NetworkRTCProvider::SendToSocket>(decoder, this, &NetworkRTCProvider::sendToSocket);
        return;
    }
    if (decoder.messageName() == Messages::NetworkRTCProvider::CloseSocket::name()) {
        IPC::handleMessage<Messages::NetworkRTCProvider::CloseSocket>(decoder, this, &NetworkRTCProvider::closeSocket);
        return;
    }
    if (decoder.messageName() == Messages::NetworkRTCProvider::SetSocketOption::name()) {
        IPC::handleMessage<Messages::NetworkRTCProvider::SetSocketOption>(decoder, this, &NetworkRTCProvider::setSocketOption);
        return;
    }
    UNUSED_PARAM(connection);
    UNUSED_PARAM(decoder);
    ASSERT_NOT_REACHED();
}

} // namespace WebKit

#endif // USE(LIBWEBRTC)
