/*
 * Copyright (C) 2010-2021 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1.  Redistributions of source code must retain the above copyright
 *     notice, this list of conditions and the following disclaimer.
 * 2.  Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. AND ITS CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR ITS CONTRIBUTORS BE LIABLE FOR
 * ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#include "config.h"
#if PLATFORM(COCOA) && ENABLE(GPU_PROCESS) && ENABLE(MEDIA_STREAM)
#include "RemoteAudioMediaStreamTrackRenderer.h"

#include "Decoder.h"
#include "HandleMessage.h"
#include "RemoteAudioMediaStreamTrackRendererMessages.h"
#include "SharedMemory.h"
#include "WebCoreArgumentCoders.h"
#include <WebCore/CAAudioStreamDescription.h>
#include <wtf/MediaTime.h>

namespace WebKit {

void RemoteAudioMediaStreamTrackRenderer::didReceiveMessage(IPC::Connection& connection, IPC::Decoder& decoder)
{
    if (decoder.messageName() == Messages::RemoteAudioMediaStreamTrackRenderer::Start::name()) {
        IPC::handleMessage<Messages::RemoteAudioMediaStreamTrackRenderer::Start>(decoder, this, &RemoteAudioMediaStreamTrackRenderer::start);
        return;
    }
    if (decoder.messageName() == Messages::RemoteAudioMediaStreamTrackRenderer::Stop::name()) {
        IPC::handleMessage<Messages::RemoteAudioMediaStreamTrackRenderer::Stop>(decoder, this, &RemoteAudioMediaStreamTrackRenderer::stop);
        return;
    }
    if (decoder.messageName() == Messages::RemoteAudioMediaStreamTrackRenderer::Clear::name()) {
        IPC::handleMessage<Messages::RemoteAudioMediaStreamTrackRenderer::Clear>(decoder, this, &RemoteAudioMediaStreamTrackRenderer::clear);
        return;
    }
    if (decoder.messageName() == Messages::RemoteAudioMediaStreamTrackRenderer::SetVolume::name()) {
        IPC::handleMessage<Messages::RemoteAudioMediaStreamTrackRenderer::SetVolume>(decoder, this, &RemoteAudioMediaStreamTrackRenderer::setVolume);
        return;
    }
    if (decoder.messageName() == Messages::RemoteAudioMediaStreamTrackRenderer::AudioSamplesStorageChanged::name()) {
        IPC::handleMessage<Messages::RemoteAudioMediaStreamTrackRenderer::AudioSamplesStorageChanged>(decoder, this, &RemoteAudioMediaStreamTrackRenderer::audioSamplesStorageChanged);
        return;
    }
    if (decoder.messageName() == Messages::RemoteAudioMediaStreamTrackRenderer::AudioSamplesAvailable::name()) {
        IPC::handleMessage<Messages::RemoteAudioMediaStreamTrackRenderer::AudioSamplesAvailable>(decoder, this, &RemoteAudioMediaStreamTrackRenderer::audioSamplesAvailable);
        return;
    }
    UNUSED_PARAM(connection);
    UNUSED_PARAM(decoder);
    ASSERT_NOT_REACHED();
}

} // namespace WebKit

#endif // PLATFORM(COCOA) && ENABLE(GPU_PROCESS) && ENABLE(MEDIA_STREAM)
