/*
 * Copyright (C) 2010-2021 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1.  Redistributions of source code must retain the above copyright
 *     notice, this list of conditions and the following disclaimer.
 * 2.  Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. AND ITS CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR ITS CONTRIBUTORS BE LIABLE FOR
 * ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#include "config.h"
#if ENABLE(MEDIA_STREAM)
#include "SpeechRecognitionRemoteRealtimeMediaSourceManager.h"

#include "Decoder.h"
#include "HandleMessage.h"
#if PLATFORM(COCOA)
#include "SharedMemory.h"
#endif
#include "SpeechRecognitionRemoteRealtimeMediaSourceManagerMessages.h"
#include "WebCoreArgumentCoders.h"
#if PLATFORM(COCOA)
#include <WebCore/CAAudioStreamDescription.h>
#endif
#include <WebCore/RealtimeMediaSourceIdentifier.h>
#include <wtf/MediaTime.h>

namespace WebKit {

void SpeechRecognitionRemoteRealtimeMediaSourceManager::didReceiveMessage(IPC::Connection& connection, IPC::Decoder& decoder)
{
    if (decoder.messageName() == Messages::SpeechRecognitionRemoteRealtimeMediaSourceManager::RemoteAudioSamplesAvailable::name()) {
        IPC::handleMessage<Messages::SpeechRecognitionRemoteRealtimeMediaSourceManager::RemoteAudioSamplesAvailable>(decoder, this, &SpeechRecognitionRemoteRealtimeMediaSourceManager::remoteAudioSamplesAvailable);
        return;
    }
    if (decoder.messageName() == Messages::SpeechRecognitionRemoteRealtimeMediaSourceManager::RemoteCaptureFailed::name()) {
        IPC::handleMessage<Messages::SpeechRecognitionRemoteRealtimeMediaSourceManager::RemoteCaptureFailed>(decoder, this, &SpeechRecognitionRemoteRealtimeMediaSourceManager::remoteCaptureFailed);
        return;
    }
    if (decoder.messageName() == Messages::SpeechRecognitionRemoteRealtimeMediaSourceManager::RemoteSourceStopped::name()) {
        IPC::handleMessage<Messages::SpeechRecognitionRemoteRealtimeMediaSourceManager::RemoteSourceStopped>(decoder, this, &SpeechRecognitionRemoteRealtimeMediaSourceManager::remoteSourceStopped);
        return;
    }
#if PLATFORM(COCOA)
    if (decoder.messageName() == Messages::SpeechRecognitionRemoteRealtimeMediaSourceManager::SetStorage::name()) {
        IPC::handleMessage<Messages::SpeechRecognitionRemoteRealtimeMediaSourceManager::SetStorage>(decoder, this, &SpeechRecognitionRemoteRealtimeMediaSourceManager::setStorage);
        return;
    }
#endif
    UNUSED_PARAM(connection);
    UNUSED_PARAM(decoder);
    ASSERT_NOT_REACHED();
}

} // namespace WebKit

#endif // ENABLE(MEDIA_STREAM)
